@@ -1,21 +1,21 @@
-###__PERLBIN__###
-#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2004 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    GNUpod is free software; you can redistribute it and/or modify
+#    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 3 of the License, or
+#    the Free Software Foundation; either version 2 of the License, or
 #    (at your option) any later version.
 #
-#    GNUpod is distributed in the hope that it will be useful,
+#    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -28,15 +28,13 @@ use Getopt::Long;
 use vars qw(%opts);
 
 
-print "gnupod_INIT.pl ###__VERSION__### (C) Adrian Ulrich\n";
+print "gnupod_addsong.pl Version 0.94 (C) 2002-2004 Adrian Ulrich\n";
 
 $opts{mount} = $ENV{IPOD_MOUNTPOINT};
 #Don't add xml and itunes opts.. we *NEED* the mount opt to be set..
-GetOptions(\%opts, "version", "help|h", "mount|m=s", "disable-convert|d", "france|f", "noask");
-#gnupod_INIT does not read configuration files!
+GetOptions(\%opts, "help|h", "mount|m=s", "disable-convert|d", "france|f");
 
 usage() if $opts{help};
-version() if $opts{version};
 
 go();
 
@@ -50,15 +48,15 @@ sub go {
 ## Ask the user, if he still knows what he/she's doing..
 print << "EOF";
 
-Your iPod is mounted at $opts{mount}, ok ?
+Your iPod it mounted at $opts{mount}, ok ?
 *********************************************************
 This tool creates the default directory tree on your iPod
 and creates an *empty* GNUtunesDB (..or convert your old
 iTunesDB to a new GNUtunesDB).
 
 You only have to use this command if
-    -> You never used GNUpod with this iPod
- or -> You did an 'rm -rf' on your iPod
+ a) You never used GNUpod with this iPod
+ b) You did an 'rm -rf' on your iPod
 
 btw: use 'gnupod_addsong -m $opts{mount} --restore'
      if you lost your songs on the iPod after using
@@ -71,7 +69,7 @@ Hit ENTER to continue or CTRL+C to abort
 EOF
 ##
 
-<STDIN> unless $opts{noask};
+<STDIN>;
  
  print "Creating directory structure on $opts{mount}\n\n";
  print "> AppFolders:\n";
@@ -92,44 +90,38 @@ EOF
    print "+$path\n";
  }
 
- if($opts{france}) {
-  print "> Creating 'Limit' file (because you used --france)\n";
-  mkdir("$opts{mount}/iPod_Control/Device");
-  open(LIMIT, ">$opts{mount}/iPod_Control/Device/Limit") or die "Failed: $!\n";
-   print LIMIT "216\n"; #Why?
-  close(LIMIT);
- }
- elsif(-e "$opts{mount}/iPod_Control/Device/Limit") {
-  print "> Removing 'Limit' file (because you didn't use --france)\n";
-  unlink("$opts{mount}/iPod_Control/Device/Limit");
- }
- else {
-  print "> No 'Limit' file created or deleted..\n";
- }
+if($opts{france}) {
+ print "> Creating 'Limit' file (because you used --france)\n";
+ mkdir("$opts{mount}/iPod_Control/Device");
+ open(LIMIT, ">$opts{mount}/iPod_Control/Device/Limit") or die "Failed: $!\n";
+  print LIMIT "216\n"; #Why?
+ close(LIMIT);
+}
+elsif(-e "$opts{mount}/iPod_Control/Device/Limit") {
+ print "> Removing 'Limit' file (because you didn't use --france)\n";
+ unlink("$opts{mount}/iPod_Control/Device/Limit");
+}
+else {
+ print "> No 'Limit' file created or deleted..\n";
+}
  
  print "> Creating dummy files\n";
  
- GNUpod::XMLhelper::writexml($con);
+  GNUpod::XMLhelper::writexml($con->{xml});
 
- my $t2pfail = 0;
+ 
  if(-e $con->{itunesdb} && !$opts{'disable-convert'}) {
  #We have an iTunesDB, call tunes2pod.pl
   print "Found *existing* iTunesDB, running tunes2pod.pl\n";
-  $t2pfail = system("$con->{bindir}/tunes2pod.pl", "--force", "-m", $opts{mount});
+  system("$con->{bindir}/tunes2pod.pl --force -m $opts{mount}");
  }
  else {
  #No iTunesDB, run mktunes.pl
   print "No iTunesDB found, running mktunes.pl\n";
-  $t2pfail = system("$con->{bindir}/mktunes.pl", "-m" ,"$opts{mount}");
- }
- 
- if($t2pfail) {
-  print "\n Done\n ..Looks like something went wrong :-/\n";
- }
- else {
-  print "\n Done\n   Your iPod is now ready for GNUpod :)\n";
+  system("$con->{bindir}/mktunes.pl -m $opts{mount}");
  }
  
+ print "\n Done\n   Your iPod is now ready for GNUpod :)\n";
 }
 
 
@@ -142,29 +134,16 @@ die << "EOF";
 $rtxt
 Usage: gnupod_INIT.pl [-h] [-m directory]
 
-   -h, --help              display this help and exit
-       --version           output version information and exit
-   -m, --mount=directory   iPod mountpoint, default is \$IPOD_MOUNTPOINT
-   -d, --disable-convert   Don't try to convert an existing iTunesDB
-   -f, --france            Limit volume to 100dB (For French-Law/People)
-                           Maximal-volume without this is ~104dB (VERY LOUD)
-                           *WARNING* This works only for iPods running
-                           Firmware 1.x (1st & 2nd generation)
-                           You can also use mktunes.pl '--volume PERCENT'
-                           to adjust the volume (Works with Firmware 1.x AND 2.x)
-       --noask             Do not wait for any user input
-
-Report bugs to <bug-gnupod\@nongnu.org>
-EOF
-}
-
-sub version {
-die << "EOF";
-gnupod_INIT.pl (gnupod) ###__VERSION__###
-Copyright (C) Adrian Ulrich 2002-2004
-
-This is free software; see the source for copying conditions.  There is NO
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+   -h, --help             : This ;)
+   -m, --mount=directory  : iPod mountpoint, default is \$IPOD_MOUNTPOINT
+   -d, --disable-convert  : Don't try to convert an exiting iTunesDB
+   -f, --france           : Limit volume to 100dB (For French-People)
+                            Maximal-volume without this is ~104dB (VERY LOUD)
+			    *WARNING* This works only for iPods running
+			    Firmware 1.x (1st & 2nd generation)
+                You can also use mktunes.pl '--volume PERCENT'
+                to adjust the volume (Works with Firmware 1.x AND 2.x)
 
 EOF
 }
+
